#
# spec file for package alsa-firmware
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _firmwaredir /lib/firmware
%endif
%if 0%{?suse_version} > 1220
%define _udevdir %(pkg-config --variable=udevdir udev)
%else
%define _udevdir %{_sysconfdir}/udev
%endif
Name:           alsa-firmware
Version:        1.2.4
Release:        4.8
Summary:        Firmware Data Files for ALSA
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://www.alsa-project.org/
Source:         https://www.alsa-project.org/files/pub/firmware/alsa-firmware-%{version}.tar.bz2
Source1:        usx2yaudio.rules
Source100:      https://www.alsa-project.org/files/pub/firmware/alsa-firmware-%{version}.tar.bz2.sig
Source101:      alsa-firmware.keyring
BuildRequires:  fdupes
Requires:       alsa
Supplements:    modalias(pci:v00001013d00006001sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00001013d00006003sv*sd*bc*sc*i*)
# for cs46xx
Supplements:    modalias(pci:v00001013d00006004sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v0000104Cd0000A106sv0000175Csd*bc*sc*i*)
# for asihpi
Supplements:    modalias(pci:v0000104Cd0000AC60sv0000175Csd*bc*sc*i*)
# for mixart
Supplements:    modalias(pci:v00001057d00000003sv*sd*bc*sc*i*)
# for echoaudio
Supplements:    modalias(pci:v00001057d00001801sv0000ECC0sd*bc*sc*i*)
Supplements:    modalias(pci:v00001057d00003410sv0000ECC0sd*bc*sc*i*)
# for vx
Supplements:    modalias(pci:v000010B5d00009030sv00001369sd*bc*sc*i*)
Supplements:    modalias(pci:v000010B5d00009050sv00001369sd*bc*sc*i*)
# for pcxhr
Supplements:    modalias(pci:v000010B5d00009056sv00001369sd*bc*sc*i*)
# for hdsp
Supplements:    modalias(pci:v000010EEd00003FC5sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00001102d00000002sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00001102d00000004sv*sd*bc*sc*i*)
# for emu10k1
Supplements:    modalias(pci:v00001102d00000008sv*sd*bc*sc*i*)
# for ca0132
Supplements:    modalias(pci:v00001102d00000010sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00001102d00000012sv*sd*bc*sc*i*)
Supplements:    modalias(usb:v1604p8001d*dc*dsc*dp*ic*isc*ip*in*)
# for usx2y
Supplements:    modalias(usb:v1604p8005d*dc*dsc*dp*ic*isc*ip*in*)
Supplements:    modalias(usb:v1604p8007d*dc*dsc*dp*ic*isc*ip*in*)
BuildArch:      noarch
%if 0%{?suse_version} > 1220
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(udev)
%endif

%description
Various firmware data files for ALSA drivers.

%prep
%setup -q

%build
# autoreconf -fi
%configure \
    --enable-loader \
    --enable-hotplug \
    --with-hotplug-dir=%{_firmwaredir}
%make_build

%install
%make_install
# remove duplicated entries that are already in kernel-firmware package
rm -f %{buildroot}%{_firmwaredir}/ctefx.bin
rm -f %{buildroot}%{_firmwaredir}/ctspeq.bin
# remove unnecessary loader firmwares
for d in vxloader mixartloader pcxhrloader; do
  rm -rf %{buildroot}%{_datadir}/alsa/firmware/$d
done
# some files are included in the new "kernel-firmware" package
for d in ess korg sb16 yamaha; do
  rm -rf %{buildroot}%{_firmwaredir}/$d
done
# change identical files to symlinks for hdsploader
pushd %{buildroot}%{_datadir}/alsa/firmware/hdsploader
for i in *.bin; do
  hotplug=%{buildroot}%{_firmwaredir}/$i
  if [ -f $hotplug ]; then
    if cmp -s -b $hotplug $i; then
      rm $i
      ln -s %{_firmwaredir}/$i
    fi
  fi
done
popd
# FIXME: remove non-existing msnd firmware symlinks
rm -rf %{buildroot}%{_firmwaredir}/turtlebeach
# install documents
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{_licensedir}/%{name}
install -c -m 0644 COPYING %{buildroot}%{_licensedir}/%{name}
install -c -m 0644 README %{buildroot}%{_docdir}/%{name}
for d in echoaudio hdsploader mixartloader pcxhrloader usx2yloader vxloader asihpi ca0132; do
  (cd $d
  n=${d##*/}
  mkdir -p %{buildroot}%{_docdir}/%{name}/$n
  for f in AUTHORS ChangeLog README* TODO *.txt; do
    test -f $f || continue
    case $f in
	licen[cs]e*)
	    mkdir -p %{buildroot}%{_licensedir}/%{name}/$n
	    install -c -m 0644 $f %{buildroot}%{_licensedir}/%{name}/$n
	    ;;
	*)
	    install -c -m 0644 $f %{buildroot}%{_docdir}/%{name}/$n
	    ;;
    esac
  done
  )
done
# udev rules
install -D -c -m 0644 %{SOURCE1} %{buildroot}%{_udevdir}/rules.d/52-usx2yaudio.rules
%fdupes -s %{buildroot}

%files
%doc %{_docdir}/%{name}
%license %{_licensedir}/%{name}
%{_firmwaredir}/*
%{_datadir}/alsa
%{_udevdir}

%changelog
* Tue Apr 26 2022 Dirk Müller <dmueller@suse.com>
- refresh spec file
- add gpg validation, use https
* Thu Nov 26 2020 tiwai@suse.de
- Fix build with older distros without %%_firmwaredir
* Wed Oct 21 2020 tiwai@suse.de
- Update to alsa-firmware 1.2.4:
  rework in auto-tools and Makefiles
  See details in
    https://alsa-project.org/wiki/Changes_v1.2.3.2_v1.2.4
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- use %%_firmwaredir
* Tue Jan 14 2020 tiwai@suse.de
- Comment out superfluous buildreq automake
- Run fdupes for reducing the duplications
- Remove conflicting CA0132 files against kernel-firmware
- Add supplements for the automatic installation
- Install license-related files into licensesdir
- Drop the support for old distros (<1200), drop old udev rules
* Fri Nov 15 2019 tiwai@suse.de
- Update to alsa-firmare 1.2.1:
  * Change FSF address (Franklin Street)
  * Fix up aica firmware licensing
  * Add new firmware for Creative CA0132 HD-Audio Codec
* Tue May 28 2019 tiwai@suse.de
- Install missing firmware files for CA0132 codec (bsc#1136638)
* Thu Feb 26 2015 tiwai@suse.de
- Update to alsa-firmware 1.0.29:
  update asihpi firmware to version 4.14
* Wed Jun 18 2014 tiwai@suse.de
- Updated to alsa-firmware 1.0.28:
  Removed obsoleted patch
  0001-Add-cs46xx-entry-to-the-main-configure-and-Makefile..patch:
* Thu Feb  6 2014 tiwai@suse.de
- 0001-Add-cs46xx-entry-to-the-main-configure-and-Makefile..patch:
  Add firmware files for cs46xx that have been cut since 3.13
  kernel
* Fri Apr 12 2013 tiwai@suse.de
- Updated to version 1.0.27:
  add firmware files for CA0132 HD-audio codec
- Fix macros for udev rules installation path
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; Update asihpi firmware to 4.10.05
* Thu Dec 22 2011 crrodriguez@opensuse.org
- alsa firmware is of no use without alsa
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Jan 31 2011 tiwai@suse.de
- Updated to version 1.0.24.1:
  * including previous fixes
  * Add firmware for HDSP RPM
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * update asihpi firmware version 40304
* Wed Feb 24 2010 aj@suse.de
- Use ATTR instead of SYSFS for udev rules.
* Mon Oct  5 2009 tiwai@suse.de
- really exclude firmware files in kernel-firmware package
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * just a version number bump
* Tue May  5 2009 tiwai@suse.de
- exclude some firmware files already contained in kernel-firmware
  package
* Thu Mar  5 2009 ro@suse.de
- fix build
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * updated PCXHR firmwares
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17:
  * just a version bump
* Thu Jun 26 2008 tiwai@suse.de
- updated to version 1.0.17-rc2:
  * update asihpi firmwares
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Mon Jan 28 2008 tiwai@suse.de
- changed the package version number to 1.0.16 to match with
  alsa-tools.
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * updated asihpi firmware data
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15-final:
  * including all previous fixes
* Mon Jul 30 2007 tiwai@suse.de
- updated to firmware version (as of HG 2007.07.27)
  including the latest ASIHPI binaries
- fixed udev rules for the recent 10.3 kernel.
  keep the old config for older kernels.
* Tue Jun  5 2007 tiwai@suse.de
- removed alsa from BuildRequires
- fixed filelist to be independent from alsa.rpm
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final:
  * aica firmware
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4
  * emu micro_dock firmware
* Sun Mar 18 2007 aj@suse.de
- /lib/firmware is now in filesystem package.
* Wed Mar 14 2007 tiwai@suse.de
- updated to version 1.0.14rc3:
  * updated asihpi firmwares
  * added msnd-pinnacle firmwares
  * fix usx2yaudio udev rules to call with proper -m option
* Wed Dec 20 2006 tiwai@suse.de
- updated to version 1.0.14rc1:
  * added ymfpci, maestro3, korg1212 firmwares
  * added wavefront and sb16 firmwares
  * added emi26/emi62 firmwares
* Thu Oct  5 2006 tiwai@suse.de
- updated to version 1.0.13-final:
  * no real change since rc2
* Fri Sep 22 2006 tiwai@suse.de
- updated to version 1.0.13rc2:
  * echoaduio firmware fixes
* Wed Aug 16 2006 tiwai@suse.de
- moved firmware-specific udev rules for usx2yaudio from alsa
  package.
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1:
  * new firmwares for asihpi driver
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc2.
* Sat Aug 20 2005 schwab@suse.de
- Don't require hotplug.
* Thu Jun  2 2005 tiwai@suse.de
- updated to version 1.0.9-final.
* Tue May 24 2005 tiwai@suse.de
- updated to version 1.0.9rc4.
- enable loaders, use symlinks for identical files.
* Thu Jan 13 2005 tiwai@suse.de
- updated to version 1.0.8-final.
* Fri Jan  7 2005 tiwai@suse.de
- added alsa to neededforpackage for $(datadir)/alsa ownership.
* Wed Jan  5 2005 tiwai@suse.de
- split from alsa-tools: version 1.0.8rc2.
